@@ -1,10 +1,14 @@
 import kubernetes
 
-from ocp_resources.constants import PROTOCOL_ERROR_EXCEPTION_DICT
-from ocp_resources.resource import TIMEOUT, NamespacedResource
+from ocp_resources.constants import PROTOCOL_ERROR_EXCEPTION_DICT, TIMEOUT_4MINUTES
+from ocp_resources.logger import get_logger
+from ocp_resources.resource import NamespacedResource
 from ocp_resources.utils import TimeoutSampler
 
 
+LOGGER = get_logger(name=__name__)
+
+
 class DaemonSet(NamespacedResource):
     """
     DaemonSet object.
@@ -12,7 +16,7 @@ class DaemonSet(NamespacedResource):
 
     api_group = NamespacedResource.ApiGroup.APPS
 
-    def wait_until_deployed(self, timeout=TIMEOUT):
+    def wait_until_deployed(self, timeout=TIMEOUT_4MINUTES):
         """
         Wait until all Pods are deployed and ready.
 
@@ -22,7 +26,7 @@ class DaemonSet(NamespacedResource):
         Raises:
             TimeoutExpiredError: If not all the pods are deployed.
         """
-        self.logger.info(f"Wait for {self.kind} {self.name} to deploy all desired pods")
+        LOGGER.info(f"Wait for {self.kind} {self.name} to deploy all desired pods")
         samples = TimeoutSampler(
             wait_timeout=timeout,
             sleep=1,
@@ -42,7 +46,7 @@ class DaemonSet(NamespacedResource):
                 ):
                     return
 
-    def delete(self, wait=False, timeout=TIMEOUT, body=None):
+    def delete(self, wait=False, timeout=TIMEOUT_4MINUTES, body=None):
         """
         Delete Daemonset
 
